@@ -41,23 +41,25 @@ try:
 except ImportError:
 	print 'Psyco not installed, the program will just run slower'
 
-print "DeVeDe 3.8"
+print "DeVeDe 3.9"
+if sys.platform!="win32":
+	print "Locale: "+str(os.environ["LANG"])
 
 # append the directories where we install the devede's own modules
 tipo=-1
 try:
-	fichero=open("/usr/share/devede/devede.glade","r")
+	fichero=open("/usr/local/share/devede/devede.glade","r")
 	fichero.close()
-	tipo=0
+	tipo=1
 	found=True
 except:
 	found=False
 
 if found==False:
 	try:
-		fichero=open("/usr/local/share/devede/devede.glade","r")
+		fichero=open("/usr/share/devede/devede.glade","r")
 		fichero.close()
-		tipo=1
+		tipo=0
 		found=True
 	except:
 		found=False
@@ -198,6 +200,7 @@ global_vars["menu_alignment"]=2 # middle
 global_vars["expand_advanced"]=False
 global_vars["erase_files"]=True
 global_vars["action_todo"]=2
+global_vars["filmpath"]=""
 
 if font_path[-1]!=os.sep:
 	font_path+=os.sep
