@@ -255,40 +255,36 @@ class main_window:
 		except:
 			return 1 # if we can't open /PROC/CPUINFO, return only one CPU (just in case)
 		
-		cpu_list=[]
-		physical_id=-1
-		core_id=-1
+		siblings=1 # default values
+		cpu_cores=1 # for siblings and cpu cores
+		notfirst=False
+		ncores=0
 		while(True):
 			line=proc.readline()
+			
+			if (((line[:9]=="processor") and notfirst) or (line=="")):
+				
+				# each entry is equivalent to CPU_CORES/SIBLINGS real cores
+				# (always 1 except in HyperThreading systems, where it counts 1/2)
+				
+				ncores+=(float(cpu_cores))/(float(siblings))
+				siblings=1
+				cpu_cores=1
+
 			if line=="":
 				break
+				
 			if line[:9]=="processor":
-				current_id=-1
-				current_cores=-1
-				continue
+				notfirst=True
+			elif (line[:8]=="siblings"):
+				siblings=self.get_number(line)
+			elif (line[:9]=="cpu cores"):
+				cpu_cores=self.get_number(line)
 
-			if (line[:11]=="physical id"):
-				physical_id=self.get_number(line)
-			
-			if (line[:7]=="core id"):
-				core_id=self.get_number(line)
-
-			if (physical_id!=-1) and (core_id!=-1):
-				not_found=True
-				for element in cpu_list:
-					if (element[0]==physical_id) and (element[1]==core_id):
-						not_found=False
-						break
-				if not_found:
-					cpu_list.append([physical_id,core_id])
-				current_id=-1
-				current_cores=-1
-		
-		ncores=len(cpu_list)
-		if(ncores==0):
+		if(ncores==0.0):
 			return 1
 		else:
-			return ncores
+			return int(ncores)
 
 	# Callbacks
 
