@@ -505,6 +505,10 @@ class file_properties(newfile):
 				w.set_filename(self.file_properties["path"])
 			else:
 				w1.set_sensitive(False)
+		else:
+			if (self.global_vars["filmpath"]!=""):
+				w=self.tree.get_widget("moviefile")
+				w.set_current_folder(self.global_vars["filmpath"])
 		
 		w=self.tree.get_widget("moviefile")
 		self.file_filter_videos=gtk.FileFilter()
@@ -718,7 +722,7 @@ class file_properties(newfile):
 	
 	def on_sub_add_clicked(self,widget):
 		
-		window=ask_subtitle(self.gladefile)
+		window=ask_subtitle(self.gladefile,self.global_vars["filmpath"])
 		ret=window.run()
 		window=None
 		if ret!=None:
@@ -811,6 +815,8 @@ class file_properties(newfile):
 			self.set_global_values()
 			self.set_film_buttons()
 			return
+
+		self.global_vars["filmpath"]=os.path.split(filename)[0]
 		
 		if self.change_file:
 			self.set_widgets()
@@ -944,7 +950,7 @@ class file_properties(newfile):
 					if (current_file=="") or (current_file==None):
 						devede_dialogs.show_error(self.gladefile,_("Please, add a movie file before adding subtitles."))
 						return
-					window=ask_subtitle(self.gladefile,lista[0])
+					window=ask_subtitle(self.gladefile,self.global_vars["filmpath"],lista[0])
 					ret=window.run()
 					window=None
 					if ret!=None:
@@ -1430,7 +1436,7 @@ class file_properties(newfile):
 
 class ask_subtitle:
 	
-	def __init__(self,gladefile,filename=None):
+	def __init__(self,gladefile,filepath,filename=None):
 
 		self.gladefile=gladefile
 		self.tree=gtk.glade.XML(self.gladefile,"add_subtitle",domain="devede")
@@ -1440,6 +1446,9 @@ class ask_subtitle:
 		w=self.tree.get_widget("sub_language")
 		w.child.set_text("EN (ENGLISH)")
 		self.window=self.tree.get_widget("add_subtitle")
+		if (filepath!=""):
+			w=self.tree.get_widget("subtitles_chooser")
+			w.set_current_folder(filepath)
 		if (filename!=None) and (filename!=""):
 			self.tree.get_widget("subtitles_chooser").set_filename(filename)
 		self.window.show()
