@@ -41,12 +41,16 @@ class xml_files(devede_executor.executor):
 		if do_menu:
 			if self.create_menu_stream(structure,menu_PAL,menu_widescreen,menu_path,activecolor,align):
 				return _("Failed to write to the destination directory.\nCheck that you have privileges and free space there.")
-			if None==self.create_menu_bg(structure, menu_bg, menu_PAL, font_name, bgcolor, fontcolor, activecolor, align,extcr):
+			if None==self.create_menu_bg(structure, menu_bg, menu_PAL, font_name, bgcolor, fontcolor, activecolor, align,extcr,0):
 				return _("Can't find the menu background.\nCheck the menu options.")
-			if None==self.create_menu_bg(structure, menu_bg, menu_PAL, font_name, bgcolor, fontcolor, activecolor, align,extcr,False):
+			if None==self.create_menu_bg(structure, menu_bg, menu_PAL, font_name, bgcolor, fontcolor, activecolor, align,extcr,1):
 				return _("Failed to write to the destination directory.\nCheck that you have privileges and free space there.")
-			if self.reduce_colors():
-				return _("Can't reduce menu colors.\nCheck that you have ImageMagic's Convert installed")
+			if None==self.create_menu_bg(structure, menu_bg, menu_PAL, font_name, bgcolor, fontcolor, activecolor, align,extcr,2):
+				return _("Failed to write to the destination directory.\nCheck that you have privileges and free space there.")
+			if None==self.create_menu_bg(structure, menu_bg, menu_PAL, font_name, bgcolor, fontcolor, activecolor, align,extcr,3):
+				return _("Failed to write to the destination directory.\nCheck that you have privileges and free space there.")
+			#if self.reduce_colors():
+			#	return _("Can't reduce menu colors.\nCheck that you have ImageMagic's Convert installed")
 			if self.create_menu_mpg(menu_PAL,path):
 				return _("Menu generation failed.")
 			if self.menu_mplex_buttons():
@@ -75,18 +79,27 @@ class xml_files(devede_executor.executor):
 			# MENU
 			
 			fichero.write("\t\t<menus>\n")
-			if do_menu:
-				fichero.write('\t\t\t<video format="')
-				if menu_PAL:
-					fichero.write("pal")
-				else:
-					fichero.write("ntsc")
-				fichero.write('" aspect="')
-				if menu_widescreen:
-					fichero.write("16:9")
-				else:
-					fichero.write("4:3")
-				fichero.write('"> </video>\n')
+			if do_menu==False:
+				for element in structure:
+					for element2 in element[1:]:
+						if element2["fps"]==25:
+							menu_PAL=True
+						else:
+							menu_PAL=False
+						break
+
+				
+			fichero.write('\t\t\t<video format="')
+			if menu_PAL:
+				fichero.write("pal")
+			else:
+				fichero.write("ntsc")
+			fichero.write('" aspect="')
+			if menu_widescreen:
+				fichero.write("16:9")
+			else:
+				fichero.write("4:3")
+			fichero.write('"> </video>\n')
 				
 			fichero.write('\t\t\t<pgc>\n')
 			fichero.write('\t\t\t\t<pre>\n')
@@ -227,14 +240,11 @@ class xml_files(devede_executor.executor):
 			menu_wide=""
 
 		try:
-		
 			fichero=open(self.filefolder+self.filename+"_menu.xml","w")
-			fichero.write('<subpictures>\n<stream>\n<spu force="yes" start="00:00:00.00" transparent="')
-			if activecolor[0]<32768:
-				fichero.write('ff0000"')
-			else:
-				fichero.write('00ffff"')
-			fichero.write(' highlight="'+self.filefolder+self.filename+"_menu_bg_active_out.png"+'" >\n')
+			fichero.write('<subpictures>\n<stream>\n<spu force="yes" start="00:00:00.00"')# transparent="000000"')
+			fichero.write(' image="'+self.filefolder+self.filename+'_menu_bg_inactive_out.png"')
+			fichero.write(' highlight="'+self.filefolder+self.filename+'_menu_bg_active_out.png"')
+			fichero.write(' select="'+self.filefolder+self.filename+'_menu_bg_select_out.png" >\n')
 			if menu_PAL:
 				coord_y=[(54,91),(92,129),(130,167),(168,205),(206,243),(244,281),(282,321),(322,359),(360,397),(398,437),(438,475),(476,513)]
 			else:
@@ -284,6 +294,16 @@ class xml_files(devede_executor.executor):
 		cr.set_font_size(fontsize2)
 		xb,y2,width,h2,cx,cy2=cr.text_extents(texto)
 
+		#if ((bgcolor[0]<512) and (bgcolor[1]<512) and (bgcolor[2]<512)):
+		#	bgcolor[0]=512
+		#	bgcolor[1]=512
+		#	bgcolor[2]=512
+			
+		#if ((fontcolor[0]<512) and (fontcolor[1]<512) and (fontcolor[2]<512)):
+		#	fontcolor[0]=512
+		#	fontcolor[1]=512
+		#	fontcolor[2]=512
+			
 		cor=float(bgcolor[0])/65535.0
 		cog=float(bgcolor[1])/65535.0
 		cob=float(bgcolor[2])/65535.0
@@ -305,11 +325,18 @@ class xml_files(devede_executor.executor):
 		cr.show_text(texto)
 
 
-	def create_menu_bg(self,structure,menu_bg,menu_PAL,fontname,bgcolor,fontcolor,activecolor,align,extcr=None,paint_bg=True):
+	def create_menu_bg(self,structure,menu_bg,menu_PAL,fontname,bgcolor,fontcolor,activecolor,align,extcr=None,paint_bg=0):
+
+		""" Paints the menu in a Cairo surface.	PAINT_BG can be:
+			0: paints everything for the base picture
+			1: paints the HIGHLIGHT picture
+			2: paints the ACTIVE picture
+			3: paints the SELECT picture		
+		"""
 
 		wide=False
 		
-		if paint_bg:
+		if paint_bg==0:
 			try:
 				sf_base=cairo.ImageSurface.create_from_png(menu_bg)
 			except:
@@ -323,21 +350,28 @@ class xml_files(devede_executor.executor):
 		sf=cairo.ImageSurface(cairo.FORMAT_ARGB32,720,int(y))
 
 		cr=cairo.Context(sf)
+
+		if paint_bg!=0:
+			# turn off font antialias (reduces color use in the image, same thing as using convert.exe)
+			fo = cairo.FontOptions()
+			fo.set_antialias(cairo.ANTIALIAS_NONE)
+			
+			cr.set_font_options(fo)
+			# turn off antialias
+			cr.set_antialias(cairo.ANTIALIAS_NONE)
+		
 		cr.identity_matrix()
 		
-		if paint_bg:
+		if paint_bg==0:
 			wbase=float(sf_base.get_width())
 			hbase=float(sf_base.get_height())
 			cr.scale(720.0/wbase,y/hbase)
 			cr.set_source_surface(sf_base)
 			cr.paint()
 			cr.identity_matrix()
-		else:
-			if activecolor[0]<32768:
-				cr.set_source_rgb(1.0, 0.0, 0.0)
-			else:
-				cr.set_source_rgb(0.0, 1.0, 1.0)
-			cr.paint()
+		#else:
+		#	cr.set_source_rgb(0.0, 0.0, 0.0)
+		
 
 		if wide:
 			cr.scale(0.75*sf.get_width(),1.33*sf.get_height()) # picture gets from 0 to 1 in X and from 0 to 0.75 in Y
@@ -388,23 +422,37 @@ class xml_files(devede_executor.executor):
 			fontsize=float(font_elements[-1])
 		except:
 			fontsize=12
-	
-		for entrada in structure:
-			if paint_bg:
-				self.menu_set_text(cr,pos_y,entrada[0]["nombre"],wide,bgcolor,fontcolor,fontname,fontstyle,fontslant,fontsize)
-			else:
-				self.menu_set_text(cr,pos_y,entrada[0]["nombre"],wide,[0,0,0,0],activecolor,fontname,fontstyle,fontslant,fontsize)
-			pos_y+=0.05
+		
+		if paint_bg<2:
+			for entrada in structure:
+				if paint_bg==0:
+					self.menu_set_text(cr,pos_y,entrada[0]["nombre"],wide,bgcolor,fontcolor,fontname,fontstyle,fontslant,fontsize)
+				elif paint_bg==1:
+					self.menu_set_text(cr,pos_y,entrada[0]["nombre"],wide,[0,0,0,0],activecolor,fontname,fontstyle,fontslant,fontsize)
+				elif paint_bg==2:
+					self.menu_set_text(cr,pos_y,entrada[0]["nombre"],wide,[0,0,0,0],fontcolor,fontname,fontstyle,fontslant,fontsize)
+				else:
+					self.menu_set_text(cr,pos_y,entrada[0]["nombre"],wide,[0,0,0,0],fontcolor,fontname,fontstyle,fontslant,fontsize)
+				pos_y+=0.05
 
 		if extcr==None:
-			if paint_bg:
+			if paint_bg==0:
 				sf.write_to_png(self.filefolder+self.filename+"_menu_bg.png")
+			elif paint_bg==1:
+				sf.write_to_png(self.filefolder+self.filename+"_menu_bg_active_out.png")
+			elif paint_bg==2:
+				sf.write_to_png(self.filefolder+self.filename+"_menu_bg_inactive_out.png")
 			else:
-				sf.write_to_png(self.filefolder+self.filename+"_menu_bg_active.png")
+				sf.write_to_png(self.filefolder+self.filename+"_menu_bg_select_out.png")
 		return sf
 	
 	
 	def reduce_colors(self):
+		self.reduce_colors2("inactive")
+		self.reduce_colors2("active")
+		self.reduce_colors2("select")
+	
+	def reduce_colors2(self,filename):
 	
 		print "Reducing menu colors"
 	
@@ -414,17 +462,17 @@ class xml_files(devede_executor.executor):
 		else:
 			command_var=["convert"]
 	
-		currentfile=self.filefolder+self.filename+"_menu_bg_active.png"
+		currentfile=self.filefolder+self.filename+"_menu_bg_"+filename+".png"
 		
 		origDir=os.getcwd()
 		if sys.platform=="win32":
-			temp=os.path.split(self.filefolder+self.filename+"_menu_bg_active.png")
+			temp=os.path.split(self.filefolder+self.filename+"_menu_bg_"+filename+".png")
 			picDir=temp[0]
 			picName=temp[1]
 			command_var.append(picName)
 			os.chdir(picDir)
 		else:
-			command_var.append(self.filefolder+self.filename+"_menu_bg_active.png")
+			command_var.append(self.filefolder+self.filename+"_menu_bg_"+filename+".png")
 			
 		command_var.append("-colors")
 		command_var.append("2")
@@ -433,13 +481,13 @@ class xml_files(devede_executor.executor):
 		
 		origDir=os.getcwd()
 		if sys.platform=="win32":
-			temp=os.path.split(self.filefolder+self.filename+"_menu_bg_active_out.png")
+			temp=os.path.split(self.filefolder+self.filename+"_menu_bg_"+filename+"_out.png")
 			picDir=temp[0]
 			picName=temp[1]
 			command_var.append(picName)
 			os.chdir(picDir)
 		else:
-			command_var.append(self.filefolder+self.filename+"_menu_bg_active_out.png")
+			command_var.append(self.filefolder+self.filename+"_menu_bg_"+filename+"_out.png")
 		
 		print "Lanzo "+str(command_var)
 
